@@ -91,7 +91,7 @@ def client_ping_response(client):
     """
     ping_response = subprocess.call(
         ['/sbin/ping', '-c1', client.ip_address],
-        stdout=subprocess.STDOUT,
+        stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
     )
     return ping_response
